pytilities.types.numerictype — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »

# pytilities.types.numerictype

class `pytilities.types.numerictype.` `NumericType`

  Represents any numeric type.

  Numeric strings, ints, floats and infinity are indirect instances of this class. Ints and floats are subclasses of this class. Note that a string is not a subclass (some strings are numeric, but not all, and there is no numeric string type).

  `__weakref__`

    list of weak references to the object (if defined)

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.types »